aboutsummaryrefslogtreecommitdiffstats
path: root/e-util
diff options
context:
space:
mode:
authorChenthill Palanisamy <pchenthill@novell.com>2010-06-10 14:45:14 +0800
committerChenthill Palanisamy <pchenthill@novell.com>2010-06-10 14:45:14 +0800
commitc209ecc49865fc3f4d5574e6e5f8585baf12795f (patch)
tree7b8ea39ac0ddb5d4c754a1d4e4614c5cf8055fa8 /e-util
parentcc47d3318a2332790505ebaa333dbe5b8616bdd8 (diff)
downloadgsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.tar
gsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.tar.gz
gsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.tar.bz2
gsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.tar.lz
gsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.tar.xz
gsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.tar.zst
gsoc2013-evolution-c209ecc49865fc3f4d5574e6e5f8585baf12795f.zip
Check for gtk version below 2.21.1 for comptability with gseal changes
Diffstat (limited to 'e-util')
-rw-r--r--e-util/gtk-compat.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/e-util/gtk-compat.h b/e-util/gtk-compat.h
index 2bcdf9fd86..635540bb3e 100644
--- a/e-util/gtk-compat.h
+++ b/e-util/gtk-compat.h
@@ -4,10 +4,11 @@
#include <gtk/gtk.h>
/* Provide a compatibility layer for accessor functions introduced
* in GTK+ 2.22 which we need to build with sealed GDK. That way it
* is still possible to build with GTK+ 2.20. */
-#if !GTK_CHECK_VERSION(2,21,2)
+#if (GTK_MAJOR_VERSION == 2 && GTK_MINOR_VERSION < 21) \
+ || (GTK_MINOR_VERSION == 21 && GTK_MICRO_VERSION < 1)
#define gdk_drag_context_get_actions(context) (context)->actions
#define gdk_drag_context_get_suggested_action(context) (context)->suggested_action
@@ -4,10 +4,11 @@
#include <gtk/gtk.h>
/* Provide a compatibility layer for accessor functions introduced
- * in GTK+ 2.22 which we need to build with sealed GDK. That way it
+ * in GTK+ 2.21.1 which we need to build with sealed GDK. That way it
* is still possible to build with GTK+ 2.20. */